Reference
=========

Complete specification for the tuning module.

.. grid:: 1 1 2 3
   :gutter: 3

   .. grid-item-card:: Inputs
      :link: inputs
      :link-type: doc

      All parameters for configuring tuning calculations.

   .. grid-item-card:: Output
      :link: output
      :link-type: doc

      Output files and directory structure.

   .. grid-item-card:: CLI
      :link: cli
      :link-type: doc

      Command-line interface usage and options.

   .. grid-item-card:: Properties
      :link: properties
      :link-type: doc

      Available property codes, units, and dependencies.

   .. grid-item-card:: Files
      :link: files
      :link-type: doc

      ETM, MOL2, CSV, and XYZ file specifications.





.. toctree::
   :maxdepth: 1
   :hidden:

   inputs
   output
   cli
   properties
   files
   
